Learn R Programming

GOCompare (version 1.0.2.2)

mostFrequentGOs: Most frequent GO terms among groups for a data.frame

Description

Provides an easy way to get the frequency of GO terms such as biological processes for a data frame and a series of features

Usage

mostFrequentGOs(df, GOterm_field)

Value

This function will return a table with the frequency of GO terms per feature

Arguments

df

A data frame with the results of a functional enrichment analysis for a species with an extra column "feature" with the features to be compared

GOterm_field

This is a string with the column name of the GO terms (e.g; "Functional.Category")

Examples

Run this code

#Loading example datasets
data(H_sapiens)
#Defining the column with the GO terms to be compared
GOterm_field <- "Functional_Category"
#Running function
x <- mostFrequentGOs(df=H_sapiens, GOterm_field=GOterm_field)
#Displaying results
head(x)

Run the code above in your browser using DataLab